@@ -6,7 +6,6 @@ require 'zlib'
 require 'multi_xml'
 require 'json'
 require 'csv'
-require 'erb'
 
 require 'httparty/module_inheritable_attributes'
 require 'httparty/cookie_hash'
@@ -39,6 +38,8 @@ module HTTParty
   # [:+timeout+:] Timeout for opening connection and reading data.
   # [:+local_host:] Local address to bind to before connecting.
   # [:+local_port:] Local port to bind to before connecting.
+  # [:+body_stream:] Allow streaming to a REST server to specify a body_stream.
+  # [:+stream_body:] Allow for streaming large files without loading them into memory.
   #
   # There are also another set of options with names corresponding to various class methods. The methods in question are those that let you set a class-wide default, and the options override the defaults on a request-by-request basis. Those options are:
   # * :+base_uri+: see HTTParty::ClassMethods.base_uri.
@@ -50,6 +51,7 @@ module HTTParty
   # * :+maintain_method_across_redirects+: see HTTParty::ClassMethods.maintain_method_across_redirects.
   # * :+no_follow+: see HTTParty::ClassMethods.no_follow.
   # * :+parser+: see HTTParty::ClassMethods.parser.
+  # * :+uri_adapter+: see HTTParty::ClassMethods.uri_adapter
   # * :+connection_adapter+: see HTTParty::ClassMethods.connection_adapter.
   # * :+pem+: see HTTParty::ClassMethods.pem.
   # * :+query_string_normalizer+: see HTTParty::ClassMethods.query_string_normalizer
@@ -69,6 +71,16 @@ module HTTParty
       default_options[:log_format] = format
     end
 
+    # Raises HTTParty::ResponseError if response's code matches this statuses
+    #
+    #   class Foo
+    #     include HTTParty
+    #     raise_on [404, 500]
+    #   end
+    def raise_on(codes = [])
+      default_options[:raise_on] = *codes
+    end
+
     # Allows setting http proxy information to be used
     #
     #   class Foo
@@ -115,7 +127,7 @@ module HTTParty
     end
 
     # Do not send rails style query strings.
-    # Specically, don't use bracket notation when sending an array
+    # Specifically, don't use bracket notation when sending an array
     #
     # For a query:
     #   get '/', query: {selected_ids: [1,2,3]}
@@ -144,7 +156,7 @@ module HTTParty
     #     default_params api_key: 'secret', another: 'foo'
     #   end
     def default_params(h = {})
-      raise ArgumentError, 'Default params must an object which respond to #to_hash' unless h.respond_to?(:to_hash)
+      raise ArgumentError, 'Default params must be an object which responds to #to_hash' unless h.respond_to?(:to_hash)
       default_options[:default_params] ||= {}
       default_options[:default_params].merge!(h)
     end
@@ -200,14 +212,18 @@ module HTTParty
     #     include HTTParty
     #     headers 'Accept' => 'text/html'
     #   end
-    def headers(h = {})
-      raise ArgumentError, 'Headers must an object which responds to #to_hash' unless h.respond_to?(:to_hash)
-      default_options[:headers] ||= {}
-      default_options[:headers].merge!(h.to_hash)
+    def headers(h = nil)
+      if h
+        raise ArgumentError, 'Headers must be an object which responds to #to_hash' unless h.respond_to?(:to_hash)
+        default_options[:headers] ||= {}
+        default_options[:headers].merge!(h.to_hash)
+      else
+        default_options[:headers] || {}
+      end
     end
 
     def cookies(h = {})
-      raise ArgumentError, 'Cookies must an object which respond to #to_hash' unless h.respond_to?(:to_hash)
+      raise ArgumentError, 'Cookies must be an object which responds to #to_hash' unless h.respond_to?(:to_hash)
       default_cookies.add_cookies(h)
     end
 
@@ -265,7 +281,9 @@ module HTTParty
     end
 
     # Declare that you wish to maintain the chosen HTTP method across redirects.
-    # The default behavior is to follow redirects via the GET method.
+    # The default behavior is to follow redirects via the GET method, except
+    # if you are making a HEAD request, in which case the default is to
+    # follow all redirects with HEAD requests.
     # If you wish to maintain the original method, you can set this option to true.
     #
     # @example
@@ -420,6 +438,17 @@ module HTTParty
       end
     end
 
+    # Allows setting a custom URI adapter.
+    #
+    #   class Foo
+    #     include HTTParty
+    #     uri_adapter Addressable::URI
+    #   end
+    def uri_adapter(uri_adapter)
+      raise ArgumentError, 'The URI adapter should respond to #parse' unless uri_adapter.respond_to?(:parse)
+      default_options[:uri_adapter] = uri_adapter
+    end
+
     # Allows setting a custom connection_adapter for the http connections
     #
     # @example
@@ -470,7 +499,7 @@ module HTTParty
     #   Foo.post('http://foo.com/resources', body: {bar: 'baz'})
     #
     #   # Simple post with full url using :query option,
-    #   # which gets set as form data on the request.
+    #   # which appends the parameters to the URI.
     #   Foo.post('http://foo.com/resources', query: {bar: 'baz'})
     def post(path, options = {}, &block)
       perform_request Net::HTTP::Post, path, options, &block
@@ -503,6 +532,7 @@ module HTTParty
 
     # Perform a HEAD request to a path
     def head(path, options = {}, &block)
+      ensure_method_maintained_across_redirects options
       perform_request Net::HTTP::Head, path, options, &block
     end
 
@@ -511,10 +541,21 @@ module HTTParty
       perform_request Net::HTTP::Options, path, options, &block
     end
 
+    # Perform a MKCOL request to a path
+    def mkcol(path, options = {}, &block)
+      perform_request Net::HTTP::Mkcol, path, options, &block
+    end
+
     attr_reader :default_options
 
     private
 
+    def ensure_method_maintained_across_redirects(options)
+      unless options.key?(:maintain_method_across_redirects)
+        options[:maintain_method_across_redirects] = true
+      end
+    end
+
     def perform_request(http_method, path, options, &block) #:nodoc:
       options = ModuleInheritableAttributes.hash_deep_dup(default_options).merge(options)
       process_headers(options)
