@@ -1,4 +1,5 @@
 require 'erb'
+require 'httparty/request/body'
 
 module HTTParty
   class Request #:nodoc:
@@ -176,10 +177,6 @@ module HTTParty
       connection_adapter.call(uri, options)
     end
 
-    def body
-      options[:body].respond_to?(:to_hash) ? normalize_query(options[:body]) : options[:body]
-    end
-
     def credentials
       (options[:basic_auth] || options[:digest_auth]).to_hash
     end
@@ -206,8 +203,8 @@ module HTTParty
 
     def setup_raw_request
       @raw_request = http_method.new(request_uri(uri))
-      @raw_request.body = body if body
       @raw_request.body_stream = options[:body_stream] if options[:body_stream]
+
       if options[:headers].respond_to?(:to_hash)
         headers_hash = options[:headers].to_hash
 
@@ -220,6 +217,16 @@ module HTTParty
           @raw_request['accept-encoding'] = @raw_request['accept-encoding']
         end
       end
+
+      if options[:body]
+        body = Body.new(options[:body], query_string_normalizer: query_string_normalizer)
+        if body.multipart?
+          content_type = "multipart/form-data; boundary=#{body.boundary}"
+          @raw_request['Content-Type'] = content_type
+        end
+        @raw_request.body = body.call
+      end
+
       if options[:basic_auth] && send_authorization_header?
         @raw_request.basic_auth(username, password)
         @credentials_sent = true
@@ -276,8 +283,10 @@ module HTTParty
     end
 
     def encode_with_ruby_encoding(body, charset)
+      # NOTE: This will raise an argument error if the
+      # charset does not exist
       encoding = Encoding.find(charset)
-      body.force_encoding(charset)
+      body.force_encoding(encoding.to_s)
     rescue ArgumentError
       body
     end
