@@ -342,6 +342,27 @@ RSpec.describe HTTParty::Request do
         expect(CGI.unescape(body)).to eq("foo=bar&foo=baz&page=1")
       end
     end
+
+    context "when body is multipart" do
+      it "sets header Content-Type: multipart/form-data; boundary=" do
+        @request.options[:body] = {file: File.open(File::NULL, 'r')}
+        @request.send(:setup_raw_request)
+        headers = @request.instance_variable_get(:@raw_request).each_header.to_a
+        headers = Hash[*headers.flatten]  # Ruby 2.0 doesn't have Array#to_h
+        expect(headers['content-type']).to match(%r{^multipart/form-data; boundary=---})
+      end
+
+      context "and header Content-Type is provided" do
+        it "overwrites the header to: multipart/form-data; boundary=" do
+          @request.options[:body] = {file: File.open(File::NULL, 'r')}
+          @request.options[:headers] = {'Content-Type' => 'application/x-www-form-urlencoded'}
+          @request.send(:setup_raw_request)
+          headers = @request.instance_variable_get(:@raw_request).each_header.to_a
+          headers = Hash[*headers.flatten]  # Ruby 2.0 doesn't have Array#to_h
+          expect(headers['content-type']).to match(%r{^multipart/form-data; boundary=---})
+        end
+      end
+    end
   end
 
   describe 'http' do
@@ -373,6 +394,18 @@ RSpec.describe HTTParty::Request do
       end
     end
 
+    it 'should handle application/vnd.api+json' do
+      ["application/vnd.api+json", "application/vnd.api+json; charset=iso8859-1"].each do |ct|
+        expect(@request.send(:format_from_mimetype, ct)).to eq(:json)
+      end
+    end
+
+    it 'should handle application/hal+json' do
+      ["application/hal+json", "application/hal+json; charset=iso8859-1"].each do |ct|
+        expect(@request.send(:format_from_mimetype, ct)).to eq(:json)
+      end
+    end
+
     it 'should handle application/json' do
       ["application/json", "application/json; charset=iso8859-1"].each do |ct|
         expect(@request.send(:format_from_mimetype, ct)).to eq(:json)
@@ -579,7 +612,7 @@ RSpec.describe HTTParty::Request do
           stub_request(:get, 'http://api.foo.com/v2')
             .to_return(body: '<hash><foo>bar</foo></hash>')
           body = ""
-          response = @request.perform { |chunk| body += chunk }
+          @request.perform { |chunk| body += chunk }
           expect(body.length).to eq(27)
         end
 
