@@ -188,6 +188,23 @@ RSpec.describe HTTParty do
         @klass.get('', cookies: {type: 'snickerdoodle'}, headers: {baz: 'spax'})
       end
     end
+
+    context 'when posting file' do
+      let(:boundary) { '------------------------c772861a5109d5ef' }
+      let(:headers) do
+        { 'Content-Type'=>"multipart/form-data; boundary=#{boundary}" }
+      end
+
+      before do
+        expect(HTTParty::Request::MultipartBoundary).to receive(:generate).and_return(boundary)
+      end
+
+      it 'changes content-type headers to multipart/form-data' do
+        stub_request(:post, "http://example.com/").with(headers: headers)
+
+        @klass.post('http://example.com', body: { file: File.open('spec/fixtures/tiny.gif')})
+      end
+    end
   end
 
   describe "cookies" do
@@ -341,11 +358,12 @@ RSpec.describe HTTParty do
 
     it "raises UnsupportedFormat when the parser cannot handle the format" do
       @klass.format :json
-      class MyParser < HTTParty::Parser
-        SupportedFormats = {}
-      end unless defined?(MyParser)
+
+      parser_class = Class.new(HTTParty::Parser)
+      parser_class::SupportedFormats = {}
+
       expect do
-        @klass.parser MyParser
+        @klass.parser parser_class
       end.to raise_error(HTTParty::UnsupportedFormat)
     end
 
